# SeaPlayer
## Descriptions
SeaPlayer is a player that works in the terminal. Works with `MP3`, `OGG`, `WAV`, `MIDI` files.

## Install 
You can use [Release](https://github.com/romanin-rf/sea-player/releases) or ***download clone repository*** install the dependencies from `requirements.txt` and run via [Python](https://www.python.org).

### For MIDI playback
***If you have Windows*** you can skip this part as ***Windows*** has a default decoder for `MIDI` and ***does not need to be installed***.


***For Linux or MacOS users:***

You need to [install the FluidSynth](https://github.com/FluidSynth/fluidsynth/wiki/Download) package in order to playback `MIDI`.

## Using
![MainScreen-v0.3.4-unrelease.1](https://github.com/romanin-rf/SeaPlayer/assets/60302782/80b1cf95-7801-4fdd-9336-4d566804735a)
![ConfigurateScreen-v0.3.4-unrelease.1](https://github.com/romanin-rf/SeaPlayer/assets/60302782/79ca17ad-d4af-4cc6-84d7-9329855746e9)
